Module ffi

Module ffi 

Base bindings to c code

Unless you are really sure you have to use them, just use crate::InstructionNumberReader for normal purpose

Structs

InstructionNumberReaderRaw
The Raw Reader Structure, corresponding to the same structure in C

Functions

createInstructionNumberReader
Mock constructor
destroyInstructionNumberReader
Mock destructor
disableInstructionNumberReader
This C function calls ioctl to stop recording instruction number, see perf_event_read
enableInstructionNumberReader
This C function calls ioctl to start recording instruction number, see perf_event_read
readInstructionNumberReader
This C function reads instruction number information by reading the file identifier, see perf_event_read