pub unsafe extern "C" fn destroyInstructionNumberReader(
reader: *mut InstructionNumberReaderRaw,
)Expand description
Mock destructor
This C function internally calls free to release the memory and sets the pointer to NULL
pub unsafe extern "C" fn destroyInstructionNumberReader(
reader: *mut InstructionNumberReaderRaw,
)Mock destructor
This C function internally calls free to release the memory and sets the pointer to NULL