pub unsafe extern "C" fn disableInstructionNumberReader(
reader: *mut InstructionNumberReaderRaw,
)Expand description
This C function calls ioctl to stop recording instruction number, see perf_event_read
pub unsafe extern "C" fn disableInstructionNumberReader(
reader: *mut InstructionNumberReaderRaw,
)This C function calls ioctl to stop recording instruction number, see perf_event_read