pub unsafe extern "C" fn enableInstructionNumberReader(
reader: *mut InstructionNumberReaderRaw,
)Expand description
This C function calls ioctl to start recording instruction number, see perf_event_read
pub unsafe extern "C" fn enableInstructionNumberReader(
reader: *mut InstructionNumberReaderRaw,
)This C function calls ioctl to start recording instruction number, see perf_event_read