pub struct InstructionNumberReaderRaw {
pub size: size_t,
/* private fields */
}Expand description
The Raw Reader Structure, corresponding to the same structure in C
Fields
size: size_tpub struct InstructionNumberReaderRaw {
pub size: size_t,
/* private fields */
}The Raw Reader Structure, corresponding to the same structure in C
size: size_t