Base bindings to c code
Unless you are really sure you have to use them, just use crate::InstructionNumberReader for normal purpose
Structs
- Instruction
Number Reader Raw - The Raw Reader Structure, corresponding to the same structure in C
Functions
- create
Instruction ⚠Number Reader - Mock constructor
- destroy
Instruction ⚠Number Reader - Mock destructor
- disable
Instruction ⚠Number Reader - This C function calls ioctl to stop recording instruction number, see perf_event_read
- enable
Instruction ⚠Number Reader - This C function calls ioctl to start recording instruction number, see perf_event_read
- read
Instruction ⚠Number Reader - This C function reads instruction number information by reading the file identifier, see perf_event_read